# Klassifikation von Daten des CERN-DIY-Detektors mit Methoden des Maschinellen Lernens

Dieses Projekt Beispiele zur Analyse von Daten, die mit dem
[**CERN DIY Teilchendetektor**](https://scoollab.web.cern.ch/diy-particle-detector)
aufgezeichnet wurden.  

Der [**CERN DIY Teilchendetektor**](https://scoollab.web.cern.ch/diy-particle-detector)
nutzt PIN Photodioden mit einem zweistufigen Verstärker, um geladene Teilchen oder auch 
durch Gamma-Strahlung erzeugte Elektronen nachzuweisen. 
Die Auslese erfolgt mit einer PC-Soundkarte mit einer Auflösung vin 16 Bit (Wertebereich -32768, 32767) 
und einer Sampling-Rate von 96 kHz, d.h. einem zeitlichen Abstand von 10,417µs. Die
aufgezeichnete Kurvenformen bilden die Basis des hier betrachteten Datensatzes. 

Aus den bipolaren Pulsen wurden zusätzlich die folgenden Merkmale bestimmt:

  - **pp_height** peak-to-peak Pulshöhe	
  - **p_ratio**   das Verhältnis der Höhe des (kleineren) zweiten Pulses und des ersten 	
  - **p_dist** 	  der zeitliche Abstand zwischen Maximum und Minimum ( in Einheiten von ca. 10µs)
  - **fwhm_1** 	  die volle Breite bei halber Höhe des ersten (kürzeren) Pulsanteils (in ~10µs-Einheiten)
  - **fwhm_2**    die volle Breite bei halber Höhe des zweiten (längeren) Pulsanteils (in ~10µs-Einheiten)

Die Grafik unten illustriert die Definition der Merkmale. Gezeigt ist der Verlauf der
Spannung für 100 Samples im Abstand von ca. 10 µs. Das gezeigte Beispiel ist nicht ganz
typisch, weil ein großer Rauschpuls den abfallenden Teil des Signalpuses überlagert. 

![Darstellung eines typischen bipolaren Signals](BipolarPulseFeatures.png).

Im Verzeichnis *data/* werden vier Dateien bereit gestellt, die unter verschiedenen
Bedingungen aufgenommene Signalpulse enthalten:

  1. *UO2.zip* aus Daten mit einer Probe Pechblende (Uran-Oxid)
  2. *shielded.zip* aus Daten mit Detektor in einer Bleiabschirmung
  3. stone.zip*  mit einem Stein aus dem Schwarzwald
  4. *ambient.zip* mit Umgebungsstrahlung (ca. 0.085 µSv/h)
  5. *Radon_f+w.zip* mit Daten einer auf einem Luftballon in Kellerluft gesammelten Probe

Die im *csv*-Format abgespeicherten Daten enthalten die Spalten\\
```
['event_number','event_time','pp_height','p_ratio','p_dist','fwhm1','fwhm2','0','1', ..., '99']
```

Üblicherweise werden die Pulse nur aufgrund der Pulshöhe *pp_height* in eine der Kategorien
'signal' oder 'background' eingeordnet, weil das alleine schon eine sehr gute Unterscheidung
ermöglicht. Diese Einteilung wird auch in den hier gezeigten Beispielen verwendet.
Für Studien zur Trennung von Signal und Untergrund stehen dann also nur noch die vier übrigen Merkmale zur Verfügung, die alleine von der Pulsform abhängen. 

Als Beispiele zur Auswertung dienen die Jupyter-Notebooks *MLsignalAnalysis.ipynb* und
*MLsignalAnalysis-keras.ipynb*, die in den Paketen *scikit-learn* und *keras/tensorflow* 
enthaltene Methoden des maschinellen Lernens verwenden. 

